==> mrx_runway-0.0.1.dev202411141435-cp310-cp310-win_amd64.whl: runway/common/schemas.py <==
#
#  MAKINAROCKS CONFIDENTIAL
#  ________________________
#
#  [2017] - [2024] MakinaRocks Co., Ltd.
#  All Rights Reserved.
#
#  NOTICE:  All information contained herein is, and remains
#  the property of MakinaRocks Co., Ltd. and its suppliers, if any.
#  The intellectual and technical concepts contained herein are
#  proprietary to MakinaRocks Co., Ltd. and its suppliers and may be
#  covered by U.S. and Foreign Patents, patents in process, and
#  are protected by trade secret or copyright law. Dissemination
#  of this information or reproduction of this material is
#  strictly forbidden unless prior written permission is obtained
#  from MakinaRocks Co., Ltd.

from typing import Any, Dict, Optional

from pydantic import BaseModel

from runway.common.values import DatabaseType


class BaseInfo:
    """Base structure of information."""

    def __init__(self, **kwarg: Dict[str, Any]) -> None:
        self.kwargs = kwarg
        for key in kwarg:
            setattr(self, key, kwarg[key])

    def __repr__(self) -> str:
        """Representation"""
        result_str = ", ".join(f"{key}={value}" for key, value in self.kwargs.items())
        return f"{self.__class__.__name__}({result_str})"

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representation of the BaseInfo object.
        """
        return self.kwargs


class DatabaseConfig(BaseModel):
    """Database connection configuration"""

    type: DatabaseType
    host: str
    port: int
    database: str
    username: str
    password: str

class URLConfig(BaseModel):
    drivername: str
    required_package: str
    query: Optional[Dict[str, str]]

==> mrx_runway-1.7.0rc9-cp310-cp310-win_amd64.whl: runway/common/schemas.py <==
#
#  MAKINAROCKS CONFIDENTIAL
#  ________________________
#
#  [2017] - [2025] MakinaRocks Co., Ltd.
#  All Rights Reserved.
#
#  NOTICE:  All information contained herein is, and remains
#  the property of MakinaRocks Co., Ltd. and its suppliers, if any.
#  The intellectual and technical concepts contained herein are
#  proprietary to MakinaRocks Co., Ltd. and its suppliers and may be
#  covered by U.S. and Foreign Patents, patents in process, and
#  are protected by trade secret or copyright law. Dissemination
#  of this information or reproduction of this material is
#  strictly forbidden unless prior written permission is obtained
#  from MakinaRocks Co., Ltd.

from typing import Any, Dict

import pydantic
from packaging.version import Version

from runway.common.values import DatabaseType

if Version(pydantic.__version__) < Version("2.0.0"):
    from pydantic import BaseModel
else:
    from pydantic.v1 import BaseModel



class BaseInfo:
    """Base structure of information."""

    def __init__(self, **kwarg: Dict[str, Any]) -> None:
        self.kwargs = kwarg
        for key in kwarg:
            setattr(self, key, kwarg[key])

    def __repr__(self) -> str:
        """Representation"""
        result_str = ", ".join(f"{key}={value}" for key, value in self.kwargs.items())
        return f"{self.__class__.__name__}({result_str})"

    def to_dict(self) -> Dict[str, Any]:
        """
        Returns a dictionary representation of the BaseInfo object.
        """
        return self.kwargs

class BasePydanticInfo(BaseModel):
    """Base Pydantic model with additional functionality"""

    def to_dict(self) -> Dict[str, Any]:
        """Convert model to dictionary"""
        return dict(self)

    def __repr__(self) -> str:
        """String representation of the model"""
        result_str = ", ".join(
            f"{key}={value}"
            for key, value in dict(self).items()
        )
        return f"{self.__class__.__name__}({result_str})"


class DatabaseConfig(BaseModel):
    """Database connection configuration"""

    type: DatabaseType
    host: str
    port: int
    database: str
    username: str
    password: str
